@@ -105,7 +105,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
             use checkout_core::transaction::TransactionController;
             use checkout_core::context::Context;
             use checkout_core::context::ContextProvider;
-            use checkout_core::checkout::handlers::{create_handler, add_item_handler, remove_item_handler, confirm_items_handler, update_contact_handler, update_shipping_address_handler, update_fulfillment_type_handler, initiate_payment_handler};
+            use checkout_core::checkout::handlers::{create_handler, add_item_handler, remove_item_handler, confirm_items_handler, update_contact_handler, update_shipping_address_handler, update_fulfillment_type_handler, initiate_payment_handler, initiate_order_handler};
 
             pub struct Config {
                 pub google_application_credentials: String,
@@ -474,6 +474,42 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
                 }
             }
 
+            #[endpoint {
+                method = PATCH,
+                path = "/checkout/{id}/initiate_order",
+            }]
+            pub async fn initiate_order_endpoint(
+                req_ctx: Arc<RequestContext<ServerContext>>,
+                path: Path<IdParam>,
+                body: TypedBody<Option<<super::#context_type_name<'_> as PaymentProcessor>::ProcessArgs>>,
+            ) -> Result<HttpResponseOk<Checkout>, HttpError> {
+                let path_params = path.into_inner();
+                let args = body.into_inner();
+                let mut ctx = req_ctx
+                    .context()
+                    .context_provider
+                    .new_context()
+                    .await
+                    .unwrap();
+
+                ctx.start_transaction().await.unwrap();
+                match initiate_order_handler(&mut ctx, &path_params.id, args).await {
+                    Ok(co) => {
+                        ctx.commit_transaction().await.unwrap();
+                        Ok(HttpResponseOk(co))
+                    }
+                    Err(err) => {
+                        ctx.abort_transaction().await.unwrap();
+                        Err(HttpError {
+                            status_code: StatusCode::BAD_REQUEST,
+                            error_code: Some(err.code.clone()),
+                            external_message: err.message.clone(),
+                            internal_message: err.message.clone(),
+                        })
+                    }
+                }
+            }
+
             // payment related endpoints
             #[derive(Serialize, Deserialize, JsonSchema)]
             pub struct CorrelationIdParam {
